<h1>Campus Default Guide Request (Proxy)</h1>
    <form method="GET" action="defaultGuide">

        <div class="form-group">
        Campus:
        <select name="campus" maxlength="7">
            <option value="seattle">seattle</option>
            <option value="bothell">bothell</option>
            <option value="tacoma">tacoma</option>
        </select>
        <input type="submit" value="Go" class="btn btn-primary btn-sm">
        </div>
    </form>
