<div><label for="changed_since_date">Changed since date:</label> <input class="changed_since_date" id="changed_since_date" name="changed_since_date" value="{{search.changed_since_date}}" size="15" type="text"></div>
